# ACCELDATA-AIRFLOW-SDK

Acceldata Airflow SDK provides support for observability of airflow dags in [ADOC](https://docs.acceldata.io/documentation/what-is-adoc-platform).

Refer to the [documentation](https://docs.acceldata.io/sdk/getting-startd-airflow) for details.